.. currentmodule:: osyris

*************
API Reference
*************

Core
====

.. autosummary::
   :toctree: generated

   Array
   Datagroup
   Dataset
   units
   Vector

Plotting
========

.. autosummary::
   :toctree: generated

   histogram1d
   histogram2d
   map
   plot
   scatter
